@@ -15,6 +15,13 @@
 import datetime
 
 import mock
+import pytest
+
+try:
+    import grpc  # noqa: F401
+except ImportError:
+    pytest.skip("No GRPC", allow_module_level=True)
+
 
 from google.api_core import exceptions
 from google.api_core import retry
@@ -175,8 +182,7 @@ def test_wrap_method_with_default_retry_and_timeout_using_sentinel(unusued_sleep
 
 @mock.patch("time.sleep")
 def test_wrap_method_with_overriding_retry_and_timeout(unusued_sleep):
-    method = mock.Mock(spec=["__call__"], side_effect=[
-                       exceptions.NotFound(None), 42])
+    method = mock.Mock(spec=["__call__"], side_effect=[exceptions.NotFound(None), 42])
     default_retry = retry.Retry()
     default_timeout = timeout.ConstantTimeout(60)
     wrapped_method = google.api_core.gapic_v1.method.wrap_method(
